#
# spec file for package ghc-microlens-ghc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name microlens-ghc
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.4.15.0
Release:        1.1
Summary:        Microlens + array, bytestring, containers, transformers
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-microlens-devel
BuildRequires:  ghc-microlens-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
Use this package instead of <http://hackage.haskell.org/package/microlens
microlens> if you don't mind depending on all dependencies here –
'Lens.Micro.GHC' reexports everything from 'Lens.Micro' and additionally
provides orphan instances of microlens classes for packages coming with GHC
(<http://hackage.haskell.org/package/array array>,
<http://hackage.haskell.org/package/bytestring bytestring>,
<http://hackage.haskell.org/package/containers containers>,
<http://hackage.haskell.org/package/transfromers transformers>).

The minor and major versions of microlens-ghc are incremented whenever the
minor and major versions of microlens are incremented, so you can depend on the
exact version of microlens-ghc without specifying the version of microlens you
need.

This package is a part of the <http://hackage.haskell.org/package/microlens
microlens> family; see the readme
<https://github.com/stevenfontanella/microlens#readme on Github>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Feb 20 2025 Peter Simons <psimons@suse.com>
- Update microlens-ghc to version 0.4.15.0.
  [#] 0.4.15.0
  * New minor release (microlens-0.4.14.0).
* Fri Apr 19 2024 Peter Simons <psimons@suse.com>
- Update microlens-ghc to version 0.4.14.3.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/microlens-ghc-0.4.14.3/src/CHANGELOG.md
* Thu Oct 12 2023 Peter Simons <psimons@suse.com>
- Update microlens-ghc to version 0.4.14.2.
  [#] 0.4.14.2
  * [#171](https://github.com/stevenfontanella/microlens/pull/171) Support bytestring 0.12
  [#] 0.4.14.1
  * [#161](https://github.com/stevenfontanella/microlens/pull/161) Fix GHC 9.4 warning for using `~` without TypeOperators
* Wed Oct 11 2023 Peter Simons <psimons@suse.com>
- Update microlens-ghc to version 0.4.14.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Dec 14 2022 Peter Simons <psimons@suse.com>
- Update microlens-ghc to version 0.4.14.1.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Tue May 17 2022 Peter Simons <psimons@suse.com>
- Update microlens-ghc to version 0.4.14.0.
  [#] 0.4.14
  * New minor release (microlens-0.4.13.0).
* Mon Nov  1 2021 psimons@suse.com
- Update microlens-ghc to version 0.4.13.1.
  [#] 0.4.13.1
  * New patch release (GHC 9.2.1).
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Nov 17 2020 psimons@suse.com
- Update microlens-ghc to version 0.4.13.
  [#] 0.4.13
  * New minor release (microlens-0.4.12.0).
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add microlens-ghc at version 0.4.12.
